import * as React from 'react';
import Box from '@mui/material/Box';
import Stepper from '@mui/material/Stepper';
import Step from '@mui/material/Step';
import StepLabel from '@mui/material/StepLabel';
import Button from '@mui/material/Button';
import Tooltip from '@mui/material/Tooltip';

import LocationStep from './steps/location/LocationStep'
import SoilStep from './steps/soilvariant/SoilStep'
import HabitatStep from './steps/habitat/HabitatStep';
import ZoneStep from './steps/zone/ZoneStep';
import SummaryStep from './steps/summary/SummaryStep';
import ResultsStep from './steps/results/ResultsStep'

const steps = [
  { 'label': 'Select location', 'component': LocationStep, 'tooltip': "Click on a location on the map" },
  { 'label': 'Choose soil', 'component': SoilStep, 'tooltip': "Describe the moisture content of your soil" },
  { 'label': 'Choose habitat', 'component': HabitatStep, 'tooltip': "Specify type of landscape to be planted" },
  { 'label': 'Select zone', 'component': ZoneStep, 'tooltip': "Specify geographical detail" },
  { 'label': 'Summary', 'component': SummaryStep, 'tooltip': "Check your inputs" },
  { 'label': 'Results', 'component': ResultsStep, 'tooltip': "List of plant species and user guide" }
];

export default function StepperWizard(props) {
  const [activeStep, setActiveStep] = React.useState(0);
  const [nextDisabled, setNextDisabled] = React.useState(true);
  const [redirectBack, setRedirectBack] = React.useState(false);

  const resetStepState = () => {
    setNextDisabled(true);
    setRedirectBack(false);
  }

  const handleNext = () => {
    if (redirectBack) {
      setActiveStep((prevActiveStep) => prevActiveStep - 1);
    } else {
      setActiveStep((prevActiveStep) => prevActiveStep + 1);
    }
    resetStepState();
  };

  const handleBack = () => {
    setActiveStep((prevActiveStep) => prevActiveStep - 1);
    resetStepState();
  };

  const handleReset = () => {
    setActiveStep(0);
    resetStepState();
    props.resetFilterState()
  };

  let CurrentStep = activeStep >= steps.length ? steps[steps.length - 1].component : steps[activeStep].component;

  return (
    <Box sx={{ width: '100%', height: '100%', display: "flex", flexDirection: "column", overflow: "hidden" }}>
      <Stepper activeStep={activeStep} sx={{ paddingRight: '3vw', paddingLeft: '3vw', marginBottom: '2vw' }}>
        {steps.map((step) => {
          return (
            <Tooltip title={step.tooltip}>
              <Step key={step.label}>
                <StepLabel>{step.label}</StepLabel>
              </Step>
            </Tooltip>
          );
        })}
      </Stepper>
      <React.Fragment>
        <CurrentStep {...props} setNextDisabled={setNextDisabled} setRedirectBack={setRedirectBack} />
        <Box sx={{ display: 'flex', flexDirection: 'row', pt: 2, pb: 2, paddingRight: '3vw', paddingLeft: '3vw' }}>
          <Button
            color="inherit"
            disabled={activeStep === 0}
            onClick={handleBack}
            sx={{ mr: 1 }}
          >
            Back
          </Button>
          <Box sx={{ flex: '1 1 auto' }} />
          {activeStep === steps.length - 1 ?
            <Button onClick={handleReset}>Reset</Button> : <Button onClick={handleNext} disabled={nextDisabled}>Next</Button>}
        </Box>
      </React.Fragment>
    </Box>
  );
}
